import React from 'react';
import { GuideCueProvider } from './guide-cue/guide-cue';
import { SignalHooksProvider } from './signal-popover';
type GuideCueProviderProps = React.ComponentProps<typeof GuideCueProvider>;
type CompassComponentsProviderProps = {
    /**
     * Dark mode to be passed to the leafygreen provider. If not provided, the
     * value will be derived from the system settings
     */
    darkMode?: boolean;
    popoverPortalContainer?: HTMLElement;
    /**
     * Either React children or a render callback that will get the darkMode
     * property passed as function properties
     */
    children?: React.ReactNode | (({ darkMode, }: {
        darkMode: boolean;
        portalContainerRef: React.Ref<HTMLElement>;
        scrollContainerRef: React.Ref<HTMLElement>;
    }) => React.ReactElement | null);
    /**
     * zIndex for the stacked elements (modal, toast, popover)
     */
    stackedElementsZIndex?: number;
} & {
    onNextGuideGue?: GuideCueProviderProps['onNext'];
    onNextGuideCueGroup?: GuideCueProviderProps['onNextGroup'];
} & {
    utmSource?: string;
    utmMedium?: string;
} & React.ComponentProps<typeof SignalHooksProvider>;
/**
 * This component combines most of the existing compass-component providers into
 * one for the purposes of being reused between compass-main (electron) and
 * compass-web. This component ONLY combines UI-related providers exported from
 * the compass-components plugin and is not intended to include all the various
 * other providers we use in the app that usually have a platform specific role
 * (like WorkspacesProviders or FileInputBackendProvider).
 *
 * A rule of thumb for adding a new provider in this component tree should be
 * whether or not it can be used completely interchangeably between electron and
 * browser environment.
 */
export declare const CompassComponentsProvider: ({ darkMode: _darkMode, children, onNextGuideGue, onNextGuideCueGroup, utmSource, utmMedium, stackedElementsZIndex, popoverPortalContainer: _popoverPortalContainer, ...signalHooksProviderProps }: CompassComponentsProviderProps) => React.JSX.Element;
export {};
//# sourceMappingURL=compass-components-provider.d.ts.map