"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tab = void 0;
const react_1 = __importStar(require("react"));
const emotion_1 = require("@leafygreen-ui/emotion");
const palette_1 = require("@leafygreen-ui/palette");
const tokens_1 = require("@leafygreen-ui/tokens");
const sortable_1 = require("@dnd-kit/sortable");
const utilities_1 = require("@dnd-kit/utilities");
const use_theme_1 = require("../../hooks/use-theme");
const leafygreen_1 = require("../leafygreen");
const merge_props_1 = require("../../utils/merge-props");
const use_default_action_1 = require("../../hooks/use-default-action");
const logo_icon_1 = require("../icons/logo-icon");
const leafygreen_2 = require("../leafygreen");
const server_icon_1 = require("../icons/server-icon");
function focusedChild(className) {
    return `&:hover ${className}, &:focus-visible ${className}, &:focus-within:not(:focus) ${className}`;
}
const tabTransition = '.16s ease-in-out';
const tabStyles = (0, emotion_1.css)({
    display: 'grid',
    gridTemplateAreas: `
    "top top top"
    "icon text close"
  `,
    gridRowGap: 0,
    gridColumnGap: tokens_1.spacing[200],
    gridTemplateRows: `${tokens_1.spacing[100]}px 1fr`,
    gridTemplateColumns: 'min-content 1fr min-content',
    '&:hover, &:focus-visible, &:focus-within:not(:focus)': {
        gridTemplateColumns: 'min-content 1fr min-content',
    },
    alignItems: 'center',
    paddingBottom: tokens_1.spacing[100],
    maxWidth: tokens_1.spacing[800] * 6,
    minWidth: tokens_1.spacing[1600] + tokens_1.spacing[800],
    height: tokens_1.spacing[1000],
    position: 'relative',
    outline: 'none',
    backgroundColor: 'var(--workspace-tab-background-color)',
    color: 'var(--workspace-tab-color)',
    boxShadow: 'inset -1px -1px 0 0 var(--workspace-tab-border-color)',
    '&:hover': {
        backgroundColor: 'inherit',
        cursor: 'pointer',
        zIndex: 1,
    },
    '&:focus-visible': {
        boxShadow: 'inset 0 0 0 1px var(--workspace-tab-border-color)',
    },
    /*
      the text makes space for the button,
      because the button takes no space
     */
    [focusedChild('.workspace-tab-title-container')]: {
        maxWidth: `calc(100% - ${tokens_1.spacing[600]}px - ${tokens_1.spacing[150]}px)`,
    },
    /*
      the button takes no space,
      so that the width does not jump as it shows/hides
     */
    [focusedChild('.workspace-tab-close-button')]: {
        display: 'inline-block',
        position: 'absolute',
        right: tokens_1.spacing[100],
        bottom: tokens_1.spacing[100] + tokens_1.spacing[50],
    },
    // instead of topBorder we use a pseudoelement, so that we can programmaticaly adjust the colors
    '&::before': {
        content: '""',
        backgroundColor: 'var(--workspace-tab-top-border-color)',
        height: tokens_1.spacing[100],
        width: '100%',
        display: 'block',
        gridArea: 'top',
    },
});
const tabLightThemeStyles = (0, emotion_1.css)({
    '--workspace-tab-background-color': palette_1.palette.gray.light3,
    '--workspace-tab-selected-background-color': palette_1.palette.white,
    '--workspace-tab-border-color': palette_1.palette.gray.light2,
    '--workspace-tab-top-border-color': 'transparent',
    '--workspace-tab-color': palette_1.palette.gray.base,
    '--workspace-tab-selected-color': palette_1.palette.gray.dark3,
    '--workspace-tab-selected-border-color': 'transparent',
    '&:focus-visible': {
        '--workspace-tab-selected-color': palette_1.palette.blue.base,
        '--workspace-tab-border-color': palette_1.palette.blue.base,
    },
});
const tabDarkThemeStyles = (0, emotion_1.css)({
    '--workspace-tab-background-color': palette_1.palette.gray.dark3,
    '--workspace-tab-selected-background-color': palette_1.palette.black,
    '--workspace-tab-border-color': palette_1.palette.gray.dark2,
    '--workspace-tab-top-border-color': 'transparent',
    '--workspace-tab-color': palette_1.palette.gray.base,
    '--workspace-tab-selected-color': palette_1.palette.white,
    '--workspace-tab-selected-border-color': 'transparent',
    '&:focus-visible': {
        '--workspace-tab-selected-color': palette_1.palette.blue.light1,
        '--workspace-tab-`border-color`': palette_1.palette.blue.light1,
    },
});
const selectedTabStyles = (0, emotion_1.css)({
    color: 'var(--workspace-tab-selected-color)',
    backgroundColor: 'var(--workspace-tab-selected-background-color)',
    boxShadow: 'inset -1px 0 0 0 var(--workspace-tab-border-color)',
    '&:hover': {
        backgroundColor: 'var(--workspace-tab-selected-background-color)',
        cursor: 'default',
    },
    '&::before': {
        backgroundColor: 'var(--workspace-tab-selected-top-border-color)',
        filter: 'brightness(0.85) saturate(2)',
    },
});
const selectedThemedTabStyles = (0, emotion_1.css)({});
const draggingTabStyles = (0, emotion_1.css)({
    cursor: 'grabbing !important',
});
const tabIconStyles = (0, emotion_1.css)({
    color: 'currentColor',
    marginLeft: tokens_1.spacing[300],
});
const tabTitleContainerStyles = (0, emotion_1.css)({
    position: 'relative',
    minWidth: 0,
    marginRight: tokens_1.spacing[100],
});
const tabTitleStyles = (0, emotion_1.css)({
    fontSize: '12px',
    lineHeight: '16px',
    fontWeight: 'normal',
    color: 'currentColor',
    whiteSpace: 'nowrap',
    overflow: 'hidden',
    textOverflow: 'ellipsis',
    transform: 'translateY(0)',
    transition: tabTransition,
    transitionProperty: 'opacity, transform',
});
const closeButtonStyles = (0, emotion_1.css)({
    display: 'none',
    marginRight: tokens_1.spacing[100],
});
const workspaceTabTooltipStyles = (0, emotion_1.css)({
    overflowWrap: 'anywhere',
    textWrap: 'wrap',
});
function Tab({ connectionName, type, title, tooltip, isSelected, isDragging, onSelect, onClose, tabContentId, iconGlyph, tabTheme, className: tabClassName, ...props }) {
    const darkMode = (0, use_theme_1.useDarkMode)();
    const defaultActionProps = (0, use_default_action_1.useDefaultAction)(onSelect);
    const { listeners, setNodeRef, transform, transition } = (0, sortable_1.useSortable)({
        id: tabContentId,
    });
    const tabProps = (0, merge_props_1.mergeProps)(defaultActionProps, listeners ?? {}, props);
    const themeClass = (0, react_1.useMemo)(() => {
        if (!tabTheme) {
            return darkMode ? tabDarkThemeStyles : tabLightThemeStyles;
        }
        return (0, emotion_1.css)(tabTheme);
    }, [tabTheme, darkMode]);
    const style = {
        transform: utilities_1.CSS.Transform.toString(transform),
        transition,
        cursor: 'grabbing !important',
    };
    return (react_1.default.createElement(leafygreen_2.Tooltip, { enabled: !!tooltip, 
        // To make sure that tooltips are always on the bottom of the tab in
        // compass-web and are not hidden by the mms top navigation bar
        align: "bottom", justify: "start", trigger: react_1.default.createElement("div", { ref: setNodeRef, style: style, className: (0, emotion_1.cx)(tabStyles, themeClass, isSelected && selectedTabStyles, isSelected && tabTheme && selectedThemedTabStyles, isDragging && draggingTabStyles, tabClassName), "aria-selected": isSelected, role: "tab", 
            // Catch navigation on the active tab when a user tabs through Compass.
            tabIndex: isSelected ? 0 : -1, "aria-controls": tabContentId, "data-testid": "workspace-tab-button", "data-connection-name": connectionName, "data-type": type, ...tabProps },
            iconGlyph === 'Logo' && (react_1.default.createElement(logo_icon_1.LogoIcon, { height: 16, color: isSelected
                    ? 'var(--workspace-tab-selected-color)'
                    : 'var(--workspace-tab-color)', role: "presentation", className: tabIconStyles, "data-testid": `workspace-tab-icon-${iconGlyph}` })),
            iconGlyph === 'Server' && (react_1.default.createElement(server_icon_1.ServerIcon, { color: isSelected
                    ? 'var(--workspace-tab-selected-color)'
                    : 'var(--workspace-tab-color)', className: tabIconStyles, "data-testid": `workspace-tab-icon-${iconGlyph}` })),
            !['Logo', 'Server'].includes(iconGlyph) && (react_1.default.createElement(leafygreen_1.Icon, { size: "small", role: "presentation", className: tabIconStyles, glyph: iconGlyph, "data-testid": `workspace-tab-icon-${iconGlyph}` })),
            react_1.default.createElement("div", { className: (0, emotion_1.cx)(tabTitleContainerStyles, 'workspace-tab-title-container') },
                react_1.default.createElement("div", { className: (0, emotion_1.cx)(tabTitleStyles, 'workspace-tab-title') }, title)),
            react_1.default.createElement(leafygreen_1.IconButton, { className: (0, emotion_1.cx)(closeButtonStyles, 'workspace-tab-close-button'), onClick: (e) => {
                    e.stopPropagation();
                    onClose();
                }, "aria-label": "Close Tab", "data-testid": "close-workspace-tab" },
                react_1.default.createElement(leafygreen_1.Icon, { glyph: "X", role: "presentation" }))) }, tooltip && (react_1.default.createElement("div", { "data-testid": "workspace-tab-tooltip" }, tooltip.map(([label, value]) => (react_1.default.createElement("div", { key: label, className: workspaceTabTooltipStyles },
        react_1.default.createElement("b", null,
            label,
            ":"),
        " ",
        value)))))));
}
exports.Tab = Tab;
//# sourceMappingURL=tab.js.map