import React from 'react';
import { Variant as ConfirmationModalVariant } from '@leafygreen-ui/confirmation-modal';
import ConfirmationModal from '../components/modals/confirmation-modal';
import type { ButtonProps } from '@leafygreen-ui/button';
export { ConfirmationModalVariant };
type ConfirmationModalProps = React.ComponentProps<typeof ConfirmationModal>;
type ConfirmationProperties = Partial<Pick<ConfirmationModalProps, 'title' | 'variant' | 'requiredInputText'>> & {
    buttonText?: React.ReactNode;
    confirmButtonProps?: Omit<ButtonProps, 'onClick'>;
    hideConfirmButton?: boolean;
    hideCancelButton?: boolean;
    description?: React.ReactNode;
    signal?: AbortSignal;
    'data-testid'?: string;
};
/**
 * Programmatically show a
 * [leafygreen ConfirmationModal](https://www.mongodb.design/component/confirmation-modal)
 * component and (optionally) await on the user input. Can be used both inside
 * and __outside__ React rendering tree. Useful when user needs to confirm an
 * action before it can be executed or to prominently display information as a
 * side-effect of some other user action.
 *
 * @example
 * async function dropDatabaseAction() {
 *   const confirmed = await showConfirmation({
 *     variant: 'danger',
 *     title: 'Are you sure you want to drop database?',
 *   });
 *
 *   if (confirmed) {
 *     dataService.dropDatabase(...)
 *   }
 * }
 *
 * @example
 * <Button
 *   onClick={() => {
 *     void showConfirmation({
 *       title: 'Details',
 *       description: <> ... </>,
 *       hideCancelButton: true,
 *       buttonText: 'OK',
 *     });
 *   }}
 * >
 *   Show detailed info
 * </Button>
 *
 * @param props ConfirmationModal rendering properties
 */
export declare const showConfirmation: (props: ConfirmationProperties) => Promise<boolean>;
export declare const ConfirmationModalArea: React.FunctionComponent;
//# sourceMappingURL=use-confirmation.d.ts.map