"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfirmationModalArea = exports.showConfirmation = exports.ConfirmationModalVariant = void 0;
const react_1 = __importStar(require("react"));
const confirmation_modal_1 = require("@leafygreen-ui/confirmation-modal");
Object.defineProperty(exports, "ConfirmationModalVariant", { enumerable: true, get: function () { return confirmation_modal_1.Variant; } });
const confirmation_modal_2 = __importDefault(require("../components/modals/confirmation-modal"));
const emotion_1 = require("@leafygreen-ui/emotion");
class GlobalConfirmationModalState {
    constructor() {
        this.confirmationId = 0;
        this.onShowCallback = null;
    }
    showConfirmation(props) {
        return new Promise((resolve, reject) => {
            this.onShowCallback?.({
                props,
                resolve,
                reject,
                confirmationId: ++this.confirmationId,
            });
        });
    }
}
const confirmationModalState = new GlobalConfirmationModalState();
/**
 * Programmatically show a
 * [leafygreen ConfirmationModal](https://www.mongodb.design/component/confirmation-modal)
 * component and (optionally) await on the user input. Can be used both inside
 * and __outside__ React rendering tree. Useful when user needs to confirm an
 * action before it can be executed or to prominently display information as a
 * side-effect of some other user action.
 *
 * @example
 * async function dropDatabaseAction() {
 *   const confirmed = await showConfirmation({
 *     variant: 'danger',
 *     title: 'Are you sure you want to drop database?',
 *   });
 *
 *   if (confirmed) {
 *     dataService.dropDatabase(...)
 *   }
 * }
 *
 * @example
 * <Button
 *   onClick={() => {
 *     void showConfirmation({
 *       title: 'Details',
 *       description: <> ... </>,
 *       hideCancelButton: true,
 *       buttonText: 'OK',
 *     });
 *   }}
 * >
 *   Show detailed info
 * </Button>
 *
 * @param props ConfirmationModal rendering properties
 */
exports.showConfirmation = confirmationModalState.showConfirmation.bind(confirmationModalState);
const hideButtonStyles = (0, emotion_1.css)({
    display: 'none !important',
});
const _ConfirmationModalArea = ({ children }) => {
    const [confirmationProps, setConfirmationProps] = (0, react_1.useState)({
        open: false,
        confirmationId: -1,
    });
    const callbackRef = (0, react_1.useRef)();
    const confirmationModalStateRef = (0, react_1.useRef)();
    if (!confirmationModalStateRef.current) {
        confirmationModalStateRef.current = confirmationModalState;
        confirmationModalStateRef.current.onShowCallback = ({ props, resolve, reject, confirmationId, }) => {
            setConfirmationProps({ open: true, confirmationId, ...props });
            const onAbort = () => {
                setConfirmationProps((state) => {
                    return { ...state, open: false };
                });
                reject(props.signal?.reason);
            };
            callbackRef.current = (confirmed) => {
                props.signal?.removeEventListener('abort', onAbort);
                resolve(confirmed);
            };
            props.signal?.addEventListener('abort', onAbort);
        };
    }
    (0, react_1.useEffect)(() => {
        return () => {
            callbackRef.current?.(false);
            if (confirmationModalStateRef.current) {
                confirmationModalStateRef.current.onShowCallback = null;
            }
        };
    }, []);
    const onUserAction = (0, react_1.useCallback)((value) => {
        setConfirmationProps((state) => {
            return { ...state, open: false };
        });
        callbackRef.current?.(value);
        callbackRef.current = undefined;
    }, []);
    const handleConfirm = (0, react_1.useCallback)(() => {
        onUserAction(true);
    }, [onUserAction]);
    const handleCancel = (0, react_1.useCallback)(() => {
        onUserAction(false);
    }, [onUserAction]);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        children,
        react_1.default.createElement(confirmation_modal_2.default
        // To make sure that confirmation modal internal state is reset for
        // every confirmation request triggered with showConfirmation method we
        // pass `confirmationId` as a component key to force React to remount it
        // when request starts
        , { 
            // To make sure that confirmation modal internal state is reset for
            // every confirmation request triggered with showConfirmation method we
            // pass `confirmationId` as a component key to force React to remount it
            // when request starts
            key: confirmationProps.confirmationId, "data-testid": confirmationProps['data-testid'] ?? 'confirmation-modal', open: confirmationProps.open, title: confirmationProps.title ?? 'Are you sure?', variant: confirmationProps.variant ?? confirmation_modal_1.Variant.Default, confirmButtonProps: {
                className: confirmationProps.hideConfirmButton
                    ? hideButtonStyles
                    : undefined,
                children: confirmationProps.buttonText ?? 'Confirm',
                onClick: handleConfirm,
                ...confirmationProps.confirmButtonProps,
            }, cancelButtonProps: {
                className: confirmationProps.hideCancelButton
                    ? hideButtonStyles
                    : undefined,
                onClick: handleCancel,
            }, requiredInputText: confirmationProps.requiredInputText ?? undefined }, confirmationProps.description)));
};
const ConfirmationModalAreaMountedContext = react_1.default.createContext(false);
const ConfirmationModalArea = ({ children, }) => {
    if ((0, react_1.useContext)(ConfirmationModalAreaMountedContext)) {
        return react_1.default.createElement(react_1.default.Fragment, null, children);
    }
    return (react_1.default.createElement(ConfirmationModalAreaMountedContext.Provider, { value: true },
        react_1.default.createElement(_ConfirmationModalArea, null, children)));
};
exports.ConfirmationModalArea = ConfirmationModalArea;
//# sourceMappingURL=use-confirmation.js.map