/**
 * Default focus ring styles. Can be used for simple cases where we want the
 * default ring with no customization at all (most of the cases in Compass)
 */
export declare const focusRing: string;
/**
 * Provides focus ring styles with a few additional options allowing to override
 * default style
 *
 * @param options
 * @param options.outer show focus ring outside the component (default: false)
 * @param options.focusWithin show focus ring on focus within instead of focus visible (default: false)
 * @param options.hover show focus ring on hover in addition to focus (default: false)
 * @param options.radius focus ring radius (default: 4px or spacing[100] from leafygreen)
 * @returns props to apply to the component
 */
export declare function useFocusRing({ outer, focusWithin, hover, radius, }?: {
    /** show focus ring outside the component (default: false) */
    outer?: boolean;
    /** show focus ring on focus within in addition to focus visible (default: false) */
    focusWithin?: boolean;
    /** show focus ring on hover in addition to focus (default: false) */
    hover?: boolean;
    /** focus ring radius (default: 4px or spacing[100] from leafygreen) */
    radius?: number;
}): {
    className: string;
};
//# sourceMappingURL=use-focus-ring.d.ts.map