"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToastArea = exports.closeToast = exports.openToast = void 0;
const react_1 = __importStar(require("react"));
const leafygreen_1 = require("../components/leafygreen");
const use_stacked_component_1 = require("./use-stacked-component");
const __1 = require("..");
const defaultToastProperties = {
    dismissible: true,
};
class GlobalToastState {
    constructor() {
        this.timeouts = new Map();
        this.toasts = new Map();
        this.onToastsChange = () => {
            /** noop */
        };
    }
    openToast(id, props) {
        this.clearTimeout(id);
        const toastProps = {
            ...defaultToastProperties,
            ...props,
            'data-testid': `toast-${id}`,
            onClose: (e) => {
                this.closeToast(id);
                props.onClose?.(e);
            },
        };
        this.toasts.set(id, toastProps);
        if (toastProps.timeout) {
            const timeoutId = setTimeout(() => {
                this.closeToast(id);
            }, toastProps.timeout);
            this.timeouts.set(id, timeoutId);
            // If we are in the node environment, unref the timeout to allow process
            // to exit (this is mostly needed for test environments)
            timeoutId.unref?.();
        }
        this.onToastsChange('push', { id, ...toastProps }, this.toasts);
    }
    closeToast(id) {
        this.clearTimeout(id);
        this.toasts.delete(id);
        this.onToastsChange('pop', { id }, this.toasts);
    }
    clearTimeout(id) {
        if (id) {
            if (this.timeouts.has(id)) {
                clearTimeout(this.timeouts.get(id));
                this.timeouts.delete(id);
            }
        }
        else {
            this.timeouts.forEach((id) => {
                clearTimeout(id);
            });
            this.timeouts.clear();
        }
    }
    clear() {
        this.clearTimeout();
        const ids = Array.from(this.toasts.keys());
        this.toasts.clear();
        return ids;
    }
}
const toastState = new GlobalToastState();
/**
 * Programmatically trigger a
 * [leafygreen Toast](https://www.mongodb.design/component/toast/code-docs)
 * component to appear on the screen. Can be used both inside and __outside__
 * React rendering tree. The latter is especially useful for triggering toast
 * showing up for any async business logic flow.
 *
 * @example
 * function insertDocumentAction() {
 *   dataService.insertOne(...).then(
 *     () => {
 *       openToast(
 *         `insert-doc-${ns}`,
 *         { variant: 'success', title: 'Successfully inserted document' }
 *       )
 *     },
 *     (err) => {
 *       openToast(
 *         `insert-doc-${ns}`,
 *         { variant: 'warning', title: 'Failed to insert document', description: err.message }
 *       )
 *     }
 *   )
 * }
 *
 * Same method can be used to update the content of the toast that is already
 * displayed
 *
 * @example
 * function insertManyDocuments() {
 *   let total = 0;
 *   for (const doc of docs) {
 *     await dataService.insertOne(doc);
 *     openToast(
 *       `insert-doc-${ns}`,
 *       { variant: 'progress', title: 'Inserting documents', progress: docs.length / ++total }
 *     )
 *   }
 * }
 *
 * @param id unique toast id that can be used to close the toast later
 * @param props Toast rendering properties
 */
exports.openToast = toastState.openToast.bind(toastState);
/**
 * Programmatically close a toast with a matching id
 *
 * @param id unique toast id
 */
exports.closeToast = toastState.closeToast.bind(toastState);
const _ToastArea = ({ children }) => {
    // NB: the way leafygreen implements this hook leads to anything specifying
    // toast methods in hooks dependencies to constantly update potentially
    // causing infinite loops of toasts. To work around that we are storing toast
    // interface in a ref so that we can safely use it inside our effects
    //
    // @see {@link https://jira.mongodb.org/browse/LG-3209}
    const toastRef = (0, react_1.useRef)((0, leafygreen_1.useToast)());
    const toastStateRef = (0, react_1.useRef)();
    if (!toastStateRef.current) {
        toastStateRef.current = toastState;
        toastStateRef.current.onToastsChange = (action, toast) => {
            if (action === 'push') {
                toastRef.current.pushToast({
                    ...toast,
                    // To be able to maintain a global state of toasts, we remove
                    // timeout prop as timeouts handled by the GlobalToast state and our
                    // timeouts logic doesn't match leafygreen out
                    timeout: null,
                });
            }
            if (action === 'pop') {
                toastRef.current.popToast(toast.id);
            }
        };
    }
    (0, react_1.useEffect)(() => {
        return () => {
            const ids = toastStateRef.current?.clear();
            ids?.forEach((id) => {
                toastRef.current.popToast(id);
            });
        };
    }, []);
    return react_1.default.createElement(react_1.default.Fragment, null, children);
};
const ToastAreaMountedContext = react_1.default.createContext(false);
const ToastArea = ({ children }) => {
    const stackedContext = (0, use_stacked_component_1.useStackedComponent)();
    // We always want to show the toast over modal or other stacked components that may hide the toast and hence +1
    const stackedElemStyles = (0, react_1.useMemo)(() => {
        const zIndex = stackedContext?.zIndex ? stackedContext.zIndex + 1 : 1;
        return (0, __1.css)({ zIndex });
    }, [stackedContext]);
    if ((0, react_1.useContext)(ToastAreaMountedContext)) {
        return react_1.default.createElement(react_1.default.Fragment, null, children);
    }
    return (react_1.default.createElement(ToastAreaMountedContext.Provider, { value: true },
        react_1.default.createElement(leafygreen_1.ToastProvider, { portalClassName: stackedElemStyles },
            react_1.default.createElement(_ToastArea, null, children))));
};
exports.ToastArea = ToastArea;
//# sourceMappingURL=use-toast.js.map